## ---- I. LOAD DATA AND DESCRIPTION ---- 
library(sp)
library(rjags)
# THE "WOLVERINE.Rdata" FILE CONTAINS THE DATA NECESSARY TO RUN THE WOLVERINES MALES AND FEMALES EMPIRICAL EXAMPLE AT THE ORIGINAL GRID CELL SIZE (2*2kms) WITH A BERNOULLI MODEL
setwd("PAB")
load("WOLVERINE.Rdata")
# DATA DESCRIPTION 
# 1. data$poly.M AND data$poly.F CONTAINS A SpatialPolygon OBJECT
#    WITH THE BOUNDARIES OF THE STUDY AREA FOR MALES AND FEMALES RESPECTIVELY
# 2. data$detectors IS A SpatialPointsDataFrame OBJECT WHICH CONTAINS THE DETECTORS (N=4551) LOCATION AT THE ORIGINAL GRID CELL SIZE
# 3. data$my.jags.input.M AND data$my.jags.input.F AREA A LIST OF NECESSARY OBJECTS TO RUN THE JAGS MODEL FOR MALES AND FEMALES, RESPECTIVELY
# 4. data$z.init.F AND data$z.init.M ARE THE INITIAL VALUES PROVIDED FOR z. 

## ---- II. QUICK PLOTS ----
par(mfrow=c(1,2),mar=c(0,0,1,0))
## ----    1. FOR MALES ---- 
## PLOT THE HABITAT POLYGON
plot(data$poly.M, col=adjustcolor("blue",alpha.f = 0.6), main="Males")
## PLOT THE DETECTORS
points(data$detectors, cex=0.1
       ,pch=21, col="black", bg="black" )
## PLOT THE DETECTIONS
detections.M <- colSums(data$my.jags.input.M$y)
points(data$detectors[detections.M>0,], cex=0.1
       ,pch=21, col="red", bg="red" )

## ----    2. FOR FEMALES ---- 
## PLOT THE HABITAT POLYGON
plot(data$poly.F,  col=adjustcolor("red",alpha.f = 0.3), main="Females")
## PLOT THE DETECTORS
points(data$detectors, cex=0.01
       ,pch=21, col="black", bg="black" )
## PLOT THE DETECTIONS
detections.F <- colSums(data$my.jags.input.F$y)
points(data$detectors[detections.F>0,], cex=0.1
       ,pch=21, col="red", bg="red" )

## ---- III. RUN THE JAGS MODEL ---- 
## ----    1. SET PARAMETERS TO TRACK 
parameters <- c("N", "sigma", "p0", "sxy", "z")
## ----    2. SET WORKING DIRECTORY WITH JAGS MODEL
setwd("PAB")

## ----    3. RUN THE MODEL
## ----    3.1 FOR MALES ---- 
# ITERATIONS ARE SET LOW BECAUSE OF THE LONG COMPUTING TIME! 
temp.model.F <- jags.model(  file = "SCR.BERNOULLI.PAB.WOLVERINE.jags"
                             , data = data$my.jags.input.F
                             , inits = data$inits.F
                             , n.chains = 1
                             , n.adapt = 10)
jagsoutput.F <- coda.samples( model = temp.model.F
                              , variable.names = parameters
                              , n.iter = 10
                              , thin = 1) 

## ----    3.2 FOR MALES ---- 
# ITERATIONS ARE SET LOW BECAUSE OF THE LONG COMPUTING TIME! 
temp.model.M <- jags.model(  file = "SCR.BERNOULLI.PAB.WOLVERINE.jags"
                             , data = data$my.jags.input.M
                             , inits = data$inits.M
                             , n.chains = 1
                             , n.adapt = 10)
jagsoutput.M <- coda.samples( model = temp.model.M
                              , variable.names = parameters
                              , n.iter = 10
                              , thin = 1) 
